summaryrefslogtreecommitdiff
path: root/src/SMAPI.Web/ViewModels
diff options
context:
space:
mode:
Diffstat (limited to 'src/SMAPI.Web/ViewModels')
-rw-r--r--src/SMAPI.Web/ViewModels/JsonValidator/JsonValidatorModel.cs7
-rw-r--r--src/SMAPI.Web/ViewModels/LogParserModel.cs16
2 files changed, 10 insertions, 13 deletions
diff --git a/src/SMAPI.Web/ViewModels/JsonValidator/JsonValidatorModel.cs b/src/SMAPI.Web/ViewModels/JsonValidator/JsonValidatorModel.cs
index 2d13bf23..5b18331f 100644
--- a/src/SMAPI.Web/ViewModels/JsonValidator/JsonValidatorModel.cs
+++ b/src/SMAPI.Web/ViewModels/JsonValidator/JsonValidatorModel.cs
@@ -9,9 +9,6 @@ namespace StardewModdingAPI.Web.ViewModels.JsonValidator
/*********
** Accessors
*********/
- /// <summary>The root URL for the log parser controller.</summary>
- public string SectionUrl { get; set; }
-
/// <summary>The paste ID.</summary>
public string PasteID { get; set; }
@@ -44,13 +41,11 @@ namespace StardewModdingAPI.Web.ViewModels.JsonValidator
public JsonValidatorModel() { }
/// <summary>Construct an instance.</summary>
- /// <param name="sectionUrl">The root URL for the log parser controller.</param>
/// <param name="pasteID">The paste ID.</param>
/// <param name="schemaName">The schema name with which the JSON was validated.</param>
/// <param name="schemaFormats">The supported JSON schemas (names indexed by ID).</param>
- public JsonValidatorModel(string sectionUrl, string pasteID, string schemaName, IDictionary<string, string> schemaFormats)
+ public JsonValidatorModel(string pasteID, string schemaName, IDictionary<string, string> schemaFormats)
{
- this.SectionUrl = sectionUrl;
this.PasteID = pasteID;
this.SchemaName = schemaName;
this.SchemaFormats = schemaFormats;
diff --git a/src/SMAPI.Web/ViewModels/LogParserModel.cs b/src/SMAPI.Web/ViewModels/LogParserModel.cs
index f4c5214b..bea79eae 100644
--- a/src/SMAPI.Web/ViewModels/LogParserModel.cs
+++ b/src/SMAPI.Web/ViewModels/LogParserModel.cs
@@ -1,3 +1,4 @@
+using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.RegularExpressions;
@@ -19,9 +20,6 @@ namespace StardewModdingAPI.Web.ViewModels
/*********
** Accessors
*********/
- /// <summary>The root URL for the log parser controller.</summary>
- public string SectionUrl { get; set; }
-
/// <summary>The paste ID.</summary>
public string PasteID { get; set; }
@@ -34,12 +32,18 @@ namespace StardewModdingAPI.Web.ViewModels
/// <summary>Whether to show the raw unparsed log.</summary>
public bool ShowRaw { get; set; }
- /// <summary>An error which occurred while uploading the log to Pastebin.</summary>
+ /// <summary>A non-blocking warning while uploading the log.</summary>
+ public string UploadWarning { get; set; }
+
+ /// <summary>An error which occurred while uploading the log.</summary>
public string UploadError { get; set; }
/// <summary>An error which occurred while parsing the log file.</summary>
public string ParseError => this.ParsedLog?.Error;
+ /// <summary>When the uploaded file will no longer be available.</summary>
+ public DateTime? Expiry { get; set; }
+
/*********
** Public methods
@@ -48,12 +52,10 @@ namespace StardewModdingAPI.Web.ViewModels
public LogParserModel() { }
/// <summary>Construct an instance.</summary>
- /// <param name="sectionUrl">The root URL for the log parser controller.</param>
/// <param name="pasteID">The paste ID.</param>
/// <param name="platform">The viewer's detected OS, if known.</param>
- public LogParserModel(string sectionUrl, string pasteID, Platform? platform)
+ public LogParserModel(string pasteID, Platform? platform)
{
- this.SectionUrl = sectionUrl;
this.PasteID = pasteID;
this.DetectedPlatform = platform;
this.ParsedLog = null;